
/// <reference path="../../main.js"/>

/// <summary>Samsung platform player methods.</summary>

var Player = {
    plugin: null, // build in player object
    state: -1, // player stae flag
    display: -1, // player display state flag
    skipState: -1,
    stopCallback: null,    /* Callback function to be set by client */
    originalSource: null,

    STOPPED: 0, // player states
    PLAYING: 1,
    PAUSED: 2,
    FORWARD: 3,
    REWIND: 4,
    COMPLETE: 5,

    FULLSCREEN: 10, // player display states
    WINDOW: 6,
    LOADING: 7,
    HIDDEN: 8,
    RESUMED: 9,

    x1: 0, // position of the player window
    y1: 0,
    x2: 0,
    y2: 0,

    url: null

}

// -----------------------------------------------------------------------
Player.init = function () {
    /// <summary>Initialization of the player.</summary>
    var success = true;

    var _this = this;

    this.state = this.STOPPED;
    this.display = this.WINDOW;

    this.plugin = document.getElementById("pluginObjectPlayer");

    //Main.log("Samsung Player: " + "init player");

    if (!this.plugin) {
        success = false;
    }
    else {
        var mwPlugin = document.getElementById("pluginObjectTVMW");

        if (!mwPlugin) {
            success = false;
        }
        else {
            /* Save current TV Source */
            //this.originalSource = mwPlugin.GetSource();

            /* Set TV source to media player plugin */
            // mwPlugin.SetMediaSource();
        }
    }

    // this.setWindow();

    this.x1 = Main.setting.VideoPlayerMovie.x1;
    this.y1 = Main.setting.VideoPlayerMovie.y1;
    this.x2 = Main.setting.VideoPlayerMovie.x2;
    this.y2 = Main.setting.VideoPlayerMovie.y2;

    this.plugin.OnCurrentPlayTime = 'Player.setCurTime';
    this.plugin.OnStreamInfoReady = 'Player.onStreamInfoReady';
    this.plugin.OnBufferingStart = 'Player.onBufferingStart';
    this.plugin.OnBufferingProgress = 'Player.onBufferingProgress';
    this.plugin.OnBufferingComplete = 'Player.onBufferingComplete';

    this.plugin.OnAuthenticationFailed = 'Player.onAuthenticationFailed';
    this.plugin.OnConnectionFailed = 'Player.onConnectionFailed';
    this.plugin.OnNetworkDisconnected = 'Player.onNetworkDisconnected';
    this.plugin.OnRenderError = 'Player.onRenderError';
    this.plugin.OnRenderingComplete = 'Player.onRenderingComplete';
    this.plugin.OnStreamNotFound = 'Player.onStreamNotFound';

    return success;
}

// -----------------------------------------------------------------------
Player.deinit = function () {
    /// <summary>Deinitialization of the player. Main command is 'stopVideo'</summary>

    //Main.log("Samsung Player: " + "player deinit");

    this.stopVideo();

    var mwPlugin = document.getElementById("pluginObjectTVMW");

    if (mwPlugin && (this.originalSource != null)) {
        /* Restore original TV source before closing the widget */

        //mwPlugin.SetSource(this.originalSource);
        ////Main.log("Samsung Player: " + "restore source to " + this.originalSource);
    }


}

// -----------------------------------------------------------------------
Player.clearScreen = function () {
    /// <summary>Player clear screen.</summary>

    this.plugin.ClearScreen;

}

// -----------------------------------------------------------------------
Player.setInitialBuffer = function (percents) {
    /// <summary>Set initial buffer size.</summary>
    /// <param name="percents" type="String">Initial buffer size in percents.</param>

    this.plugin.SetInitialBuffer(percents);

}

// ------------------------------------------------------------------------

Player.setNormalscreen = function () {

    Player.setWindow();
}

// -----------------------------------------------------------------------
Player.setWindow = function () {
    /// <summary>Set player window size.</summary>
    // (x1, y1, x2, y2)

    if (this.display == this.FULLSCREEN)
        this.display = this.WINDOW;

    this.plugin.SetDisplayArea(this.x1, this.y1, this.x2, this.y2);

    $("#pluginObjectPlayer").css("top", Main.setting.VideoBoxscreen.Top + "px");
    $("#pluginObjectPlayer").css("left", Main.setting.VideoBoxscreen.Left + "px");
    $("#pluginObjectPlayer").css("width", Main.setting.VideoBoxscreen.Width + "px");
    $("#pluginObjectPlayer").css("height", Main.setting.VideoBoxscreen.Height + "px");

}

// -----------------------------------------------------------------------
Player.setFullscreen = function () {
  /// <summary>Set fullscreen area.</summary>
  this.plugin.SetDisplayArea(0, 0, 960, 540);
  $("#pluginObjectPlayer").css("top", Main.setting.VideoFullscreen.Top + "px");
  $("#pluginObjectPlayer").css("left", Main.setting.VideoFullscreen.Left + "px");
  $("#pluginObjectPlayer").css("width", Main.setting.VideoFullscreen.Width + "px");
  $("#pluginObjectPlayer").css("height", Main.setting.VideoFullscreen.Height + "px");
  this.display = this.FULLSCREEN;

}

// -----------------------------------------------------------------------
Player.setVideoURL = function (url) {
  /// <summary>Set video url to the object.</summary>
  /// <param name="url" type="String">Path to the video.</param>

  //this.url = url = Main.setting.Server + "/rtv2go_2011-08-01-1.mp4";
  this.url = url;
}

// -----------------------------------------------------------------------
Player.playVideo = function () {
  /// <summary>Play video command. Do necessary work before video starts.</summary>

  //Main.log("Samsung Player: " + "play video command with state:" + this.state);

  if (Template.loadedControlName != "cVideo")
    return;


  if (this.url == null) {
    //Main.log("Samsung Player: " + "No videos to play");
  }
  else {

    //Main.log("Samsung Player curren state: " + this.state);

    if (this.state == this.PLAYING) {
      //this.stopVideo();
    }

    if (this.state == this.PAUSED) {
      this.resumeVideo();
      //Main.log("Samsung Player: " + "resume video (status " + this.state + ") command:" + this.url);
    } else {
      this.state = this.LOADING;
      Main.setOffScreenSaver();
      this.plugin.Play(this.url);
      //this.plugin.Play("http://res.tvbuddy.com/SampleVideos/Video01.wmv");
      //Main.log("Samsung Player: " + "play video (status " + this.state + ") command:" + this.url);
      //Main.log("Samsung Player: " + "Player should play now");
    }

    $('body').trigger('playerStateChanged', this.state);

    Audio.plugin.SetSystemMute(false);
    //Audio.plugin.SetSystemMute(0);

  }
}

// -----------------------------------------------------------------------

Player.playAudioStream = function (url) {
  //Main.log("Player.playAudioStream: " + url);
  this.plugin.SetDisplayArea(0, 0, 0, 0);

  //this.plugin.Play(url);

  this.plugin.InitPlayer(url)
  this.plugin.SetPlayerProperty(5, 'MP3', 0)
  this.plugin.StartPlayback();

}

// -----------------------------------------------------------------------
Player.pauseVideo = function () {
    /// <summary>Pause video command.</summary>

    ////Main.log("Samsung Player: " + "Player.pauseVideo Template.loadedControlName: " + Template.loadedControlName);
    //Main.log("Samsung Player: " + "state: " + this.state);

    //if (Template.loadedControlName != "cVideo")
    //    return;

    //Main.log("Samsung Player: " + "pause video");
    this.state = this.PAUSED;
    this.plugin.Pause();
    $('body').trigger('playerStateChanged', this.PAUSED);

//    if (this.state == this.LOADING) {
//      this.plugin.Pause();
//      this.state = this.PAUSED;
//      $('body').trigger('playerStateChanged', this.PAUSED);
//    }
//    else {
//        this.state = this.PAUSED;
//        //Main.log("Samsung Player: " + "pause video");
//        this.plugin.Pause();

//        $('body').trigger('playerStateChanged', this.state);
//    }

}

// -----------------------------------------------------------------------
Player.pauseVideoFromOut = function () {
  /// <summary>Pause video from external source. Not from control bar.</summary>

  //Main.log("Samsung Player: " + "this.state: " + this.state);

  this.state = this.PAUSED;
  //Main.log("Samsung Player: " + "pause video");
  this.plugin.Pause();

  $('body').trigger('playerStateChanged', this.state);

};

// ----------------------------------------------------------------------

Player.Stop = function () {
  this.stopVideo();
}

// ----------------------------------------------------------------------
Player.stopVideo = function () {
     /// <summary>Stoping the video.</summary>


    //Player.display = -1;

    this.plugin.Stop();
    Main.setOnScreenSaver();

    this.state = this.STOPPED;

    $('body').trigger('playerStateChanged', this.state);
    $("body").trigger('clipFinish', [null]);

    this.setWindow();
}

// -----------------------------------------------------------------------
Player.resumeVideo = function () {
  /// <summary>Resume the video.</summary>

  //Main.log("Samsung Player: " + "state: " + this.state);

  if (Template.loadedControlName != "cVideo")
    return;

  this.state = this.PLAYING;
  //Main.log("resume video");

  Main.setOffScreenSaver();

  if (this.state == this.STOPPED)
    this.plugin.Play(this.url);
  else;
    this.plugin.Resume();

  $('body').trigger('playerStateChanged', this.RESUMED);
  //$('body').trigger('playerStateChanged', this.state);
}

// -----------------------------------------------------------------------
Player.skipForwardVideo = function () {
    /// <summary>Skip forward video.</summary>
    this.skipState = this.FORWARD;
    this.plugin.JumpForward(5);
}

// -----------------------------------------------------------------------

Player.skipBackwardVideo = function () {
    /// <summary>Skip backward video.</summary>
    this.skipState = this.REWIND;
    this.plugin.JumpBackward(5);
}

// -----------------------------------------------------------------------
Player.skipToStartVideo = function () {
    /// <summary>Go to the beginning of a video.</summary>
    this.skipState = this.REWIND;
    this.plugin.JumpBackward(1000);
}

// -----------------------------------------------------------------------
Player.getState = function () {
    /// <summary>Get player state.</summary>
    /// <returns type="String" />
    return this.state;
}

// -----------------------------------------------------------------------
Player.hide = function () {
    /// <summary>Fire event for hiding video.</summary>

    this.display = this.HIDDEN;

    //Main.log("Samsung Player: " + "hidden 1");
    $('body').trigger('playerStateChanged', this.display);
    $('#control').trigger('playerStateChanged', this.display);

}

// -----------------------------------------------------------------------
// Global functions called directly by the player 

Player.onBufferingStart = function () {
    /// <summary>On buffering start event.</summary>

    //Main.log("Samsung Player: " + "Buffering...");

    this.state = this.LOADING;

    $('body').trigger('playerStateChanged', this.state);

    $("#timeline .timelineback").hide();
    $("#timeInfo").hide();
    $("#buffering .bufferingInfo")
        .text("Buffering ...")
        .show();


    switch (this.skipState) {
        case this.FORWARD:
            break;
        case this.REWIND:
            break;
    }
}

// -----------------------------------------------------------------------
Player.onBufferingProgress = function (percent) {
    /// <summary>Method displaying buffering progress.</summary>
    //Main.log("Samsung Player: " + "Buffering:" + percent + "%");

    if (this.state != this.LOADING) {
        this.state = this.LOADING;
        $('body').trigger('playerStateChanged', this.state);
    }


      $("#buffering .bufferingInfo")
        .text("Buffering: " + percent + "%")
        .show();
}

// -----------------------------------------------------------------------
Player.onBufferingComplete = function () {
  /// <summary>Buffering complete event.</summary>

  this.state = this.PLAYING;

    //Main.log("Samsung Player: " + "onBufferingComplete " + this.state);

    $('body').trigger('playerStateChanged', this.state);

    $("#buffering .bufferingInfo").hide();
    $("#timeline .timelineback").show();
    $("#timeInfo").show();

}

// -----------------------------------------------------------------------
Player.onAuthenticationFailed = function () {
    /// <summary>Authentcation failed event.</summary>

    //Main.log("Samsung Player: " + "AuthenticationFailed");
    Player.stopVideo();

}

// -----------------------------------------------------------------------
Player.onConnectionFailed = function () {
    /// <summary>Connection failed event.</summary>

    //Main.log("Samsung Player: " + "ConnectionFailed");
    Player.stopVideo();
    $("body").trigger('networkError', ["onConnectionFailed"]);
}

// -----------------------------------------------------------------------
Player.onNetworkDisconnected = function () {
    /// <summary>Network disconnected event.</summary>

    //Main.log("Samsung Player: " + "NetworkDisconnected");
    Player.stopVideo();
    $("body").trigger('networkError', ["onNetworkDisconnected"]);

}

// -----------------------------------------------------------------------
Player.onRenderError = function () {
    /// <summary>Render error event.</summary>

    //Main.log("Samsung Player: " + "RenderError");
    Player.stopVideo();
    $("body").trigger('networkError', ["onRenderError"]);
}

// -----------------------------------------------------------------------
Player.onRenderingComplete = function () {
    /// <summary>Render complete event. Is called when video end is reached. </summary>

    //Main.log("Samsung Player: " + "RenderingComplete");

    
    $('body').trigger('playerStateChanged', this.COMPLETE);

}

// -----------------------------------------------------------------------
Player.onStreamNotFound = function () {
    /// <summary>Stream not found event.</summary>

    //Main.log("Samsung Player: " + "StreamNotFound");
    Player.stopVideo();

}

// -----------------------------------------------------------------------
Player.setCurTime = function (time) {
  /// <summary>Timer method. Recieve current time of the video.</summary>

  //$('body').trigger('playerStateChanged', this.PLAYING);

  ////Main.log("Player.setCurTime: " + this.state + " " + time);

  if (this.state == this.PLAYING) {
    Timeline.setTime(time);
  }

}

// -----------------------------------------------------------------------
Player.onStreamInfoReady = function () {
    /// <summary>Stream info ready event. Is called when object recieve information from the server.</summary>

    //Main.log("Samsung Player: " + "OnStreamInfoReady - state:" + this.state);

    this.state = this.PLAYING;

    Timeline.setTotalTime(Player.plugin.GetDuration());

}

// ---------------------------------------------
onServerError = function () {
/// <summary>Server error event.</summary>
    //Main.log("Player: Server Error!");
}

// -----------------------------------------------------------------------

getBandwidth = function (bandwidth) { 
    //Main.log("Samsung Player: " + "getBandwidth " + bandwidth); 
}

// -----------------------------------------------------------------------

onDecoderReady = function () { 
    //Main.log("Samsung Player: " + "onDecoderReady"); 
}

// -----------------------------------------------------------------------
stopPlayer = function () {
    Player.stopVideo();
}

// -----------------------------------------------------------------------

setTottalBuffer = function (buffer) { 
    //Main.log("Samsung Player: " + "setTottalBuffer " + buffer); 
}

// -----------------------------------------------------------------------

setCurBuffer = function (buffer) { 
    //Main.log("Samsung Player: " + "setCurBuffer " + buffer); 
}

// -----------------------------------------------------------------------